@@ -44,6 +44,8 @@ if (empty($login_mode)) {
 
         $session->check();
         $view->assign('adminFlag', $session->isAdmin());
+        $s = $session->getLoginUserData();
+        $view->assign('userName', $s["us_name"]);
 
         $view->assign('message', $session->cut('message'));
     } catch (CuMAS_Exception $e) {
